pub struct DlogReaderStorage { /* private fields */ }Implementations
Sourceimpl DlogReaderStorage
impl DlogReaderStorage
Sourcepub unsafe fn init(
flags: u32,
notify: unsafe extern "C" fn(*mut c_void),
cookie: *mut c_void,
) -> impl PinInit<Self, Infallible>
pub unsafe fn init( flags: u32, notify: unsafe extern "C" fn(*mut c_void), cookie: *mut c_void, ) -> impl PinInit<Self, Infallible>
Creates a PinInit initializer for DlogReaderStorage.
Since DlogReaders typically capture containing objects via cookie, they
use 2-phase initialization to avoid races in the construction of the
DlogReader and the containing object.
Safety
The caller must ensure cookie is valid for notify.
Sourcepub fn disconnect(self: Pin<&mut Self>)
pub fn disconnect(self: Pin<&mut Self>)
Safely disconnects DlogReader.
DlogReaders must be manually stopped via disconnect to avoid reentrancy
issues in the DlogReader and its containing object.
This method must be called before the DlogReaderStorage is dropped if it
was initialized.
Sourcepub fn read(
self: Pin<&mut Self>,
flags: u32,
record: &mut dlog_record_t,
actual: &mut usize,
) -> Status
pub fn read( self: Pin<&mut Self>, flags: u32, record: &mut dlog_record_t, actual: &mut usize, ) -> Status
Reads one record from debuglog.
Upon success, returns Status::OK and sets actual to the record’s size.
Returns Status::SHOULD_WAIT if there are no records available to read.